@@ -5,6 +5,9 @@ import argparse
 import os
 import sys
 
+from prettytable import PrettyTable
+from rdflib.namespace import SH
+
 from pyshacl import __version__, validate
 from pyshacl.errors import ReportableRuntimeError, ValidationFailure
 
@@ -33,7 +36,7 @@ parser.add_argument(
     dest='ont',
     action='store',
     nargs='?',
-    help='A file path or URL to a docucument containing extra ontological information to mix into ' 'the data graph.',
+    help='A file path or URL to a document containing extra ontological information to mix into ' 'the data graph.',
 )
 parser.add_argument(
     '-i',
@@ -50,8 +53,7 @@ parser.add_argument(
     dest='metashacl',
     action='store_true',
     default=False,
-    help='Validate the SHACL Shapes graph against the shacl-shacl '
-    'Shapes Graph before before validating the Data Graph.',
+    help='Validate the SHACL Shapes graph against the shacl-shacl Shapes Graph before validating the Data Graph.',
 )
 parser.add_argument(
     '-im',
@@ -104,7 +106,7 @@ parser.add_argument(
     action='store',
     help='Choose an output format. Default is \"human\".',
     default='human',
-    choices=('human', 'turtle', 'xml', 'json-ld', 'nt', 'n3'),
+    choices=('human', 'table', 'turtle', 'xml', 'json-ld', 'nt', 'n3'),
 )
 parser.add_argument(
     '-df',
@@ -156,7 +158,7 @@ def main():
         validator_kwargs['shacl_graph'] = args.shacl
     if args.ont is not None:
         validator_kwargs['ont_graph'] = args.ont
-    if args.format != 'human':
+    if args.format not in ['human', 'table']:
         validator_kwargs['serialize_report_graph'] = args.format
     if args.inference != 'none':
         validator_kwargs['inference'] = args.inference
@@ -212,11 +214,53 @@ def main():
         import traceback
 
         traceback.print_tb(re.__traceback__)
-        sys.stderr.write("\n\nValidator encountered a Runtime Error. Please report this to the PySHACL issue tracker.")
+        sys.stderr.write(
+            "\n\nValidator encountered a Runtime Error. Please report this to the PySHACL issue tracker.\n"
+        )
         sys.exit(2)
 
     if args.format == 'human':
         args.output.write(v_text)
+    elif args.format == 'table':
+        t1 = PrettyTable()
+        t1.field_names = ["Conforms"]
+        t1.align = "c"
+        t1.add_row([is_conform])
+        args.output.write(str(t1))
+        args.output.write('\n\n')
+
+        def col_widther(s, w):
+            """Split strings to a given width for table"""
+            s2 = []
+            i = 0
+            while i < len(s):
+                s2.append(s[i : i + w])
+                i += w
+            return '\n'.join(s2)
+
+        if not is_conform:
+            t2 = PrettyTable()
+            t2.field_names = ['No.', 'Severity', 'Focus Node', 'Result Path', 'Message', 'Component', 'Shape', 'Value']
+            t2.align = "l"
+
+            for i, o in enumerate(v_graph.objects(None, SH.result)):
+                r = {}
+                for o2 in v_graph.predicate_objects(o):
+                    r[o2[0]] = str(col_widther(o2[1].replace(f'{SH}', ''), 25))  # max col width 30 chars
+                t2.add_row(
+                    [
+                        i + 1,
+                        r[SH.resultSeverity],
+                        r[SH.focusNode],
+                        r[SH.resultPath] if r.get(SH.resultPath) is not None else '-',
+                        r[SH.resultMessage],
+                        r[SH.sourceConstraintComponent],
+                        r[SH.sourceShape],
+                        r[SH.value] if r.get(SH.value) is not None else '-',
+                    ]
+                )
+                t2.add_row(['', '', '', '', '', '', '', ''])
+            args.output.write(str(t2))
     else:
         if isinstance(v_graph, bytes):
             v_graph = v_graph.decode('utf-8')
