@@ -9,8 +9,6 @@ import typing
 
 from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Optional, Set, Tuple
 
-import rdflib
-
 from rdflib import BNode, Literal, URIRef
 
 from pyshacl.consts import (
@@ -39,6 +37,7 @@ from pyshacl.rdfutil import stringify_node
 
 
 if TYPE_CHECKING:
+    from pyshacl.pytypes import RDFNode
     from pyshacl.shape import Shape
     from pyshacl.shapes_graph import ShapesGraph
 
@@ -51,6 +50,14 @@ class ConstraintComponent(object, metaclass=abc.ABCMeta):
     All Constraint Components must inherit from this class.
     """
 
+    # True if constraint component is defined as "shape-expecting"
+    shape_expecting = False
+
+    # True if constraint component is defined as "list-taking"
+    list_taking = False
+
+    shacl_constraint_component = NotImplemented
+
     def __init__(self, shape: 'Shape'):
         """
 
@@ -69,11 +76,6 @@ class ConstraintComponent(object, metaclass=abc.ABCMeta):
     def constraint_name(cls):
         raise NotImplementedError()  # pragma: no cover
 
-    @classmethod
-    @abc.abstractmethod
-    def shacl_constraint_class(cls):
-        raise NotImplementedError()  # pragma: no cover
-
     @abc.abstractmethod
     def evaluate(self, target_graph: GraphLike, focus_value_nodes: Dict, _evaluation_path: List):
         raise NotImplementedError()  # pragma: no cover
@@ -110,9 +112,9 @@ class ConstraintComponent(object, metaclass=abc.ABCMeta):
     def make_v_result_description(
         self,
         datagraph: GraphLike,
-        focus_node: 'rdflib.term.Identifier',
+        focus_node: 'RDFNode',
         severity: URIRef,
-        value_node: Optional['rdflib.term.Identifier'],
+        value_node: Optional['RDFNode'],
         messages: List[str],
         result_path=None,
         constraint_component=None,
@@ -124,7 +126,7 @@ class ConstraintComponent(object, metaclass=abc.ABCMeta):
         :param datagraph:
         :type datagraph: rdflib.Graph | rdflib.ConjunctiveGraph | rdflib.Dataset
         :param focus_node:
-        :type focus_node: rdflib.term.Identifier
+        :type focus_node: RDFNode
         :param severity:
         :type value_node: rdflib.URIRef
         :param value_node:
@@ -140,7 +142,7 @@ class ConstraintComponent(object, metaclass=abc.ABCMeta):
         :return:
         """
         sg = self.shape.sg.graph
-        constraint_component = constraint_component or self.shacl_constraint_class()
+        constraint_component = constraint_component or self.shacl_constraint_component
         constraint_name = self.constraint_name()
         if severity == SH_Violation:
             severity_desc = "Constraint Violation"
@@ -192,11 +194,11 @@ class ConstraintComponent(object, metaclass=abc.ABCMeta):
     def make_v_result(
         self,
         datagraph: GraphLike,
-        focus_node: 'rdflib.term.Identifier',
-        value_node: Optional['rdflib.term.Identifier'] = None,
-        result_path=None,
-        constraint_component=None,
-        source_constraint=None,
+        focus_node: 'RDFNode',
+        value_node: Optional['RDFNode'] = None,
+        result_path: Optional['RDFNode'] = None,
+        constraint_component: Optional['RDFNode'] = None,
+        source_constraint: Optional['RDFNode'] = None,
         extra_messages: Optional[Iterable] = None,
         bound_vars=None,
     ):
@@ -204,18 +206,19 @@ class ConstraintComponent(object, metaclass=abc.ABCMeta):
         :param datagraph:
         :type datagraph: rdflib.Graph | rdflib.ConjunctiveGraph | rdflib.Dataset
         :param focus_node:
-        :type focus_node: rdflib.term.Identifier
+        :type focus_node: RDFNode
         :param value_node:
-        :type value_node: rdflib.term.Identifier | None
+        :type value_node: RDFNode | None
         :param result_path:
-        :param bound_vars:
+        :type result_path: RDFNode | None
         :param constraint_component:
         :param source_constraint:
         :param extra_messages:
         :type extra_messages: collections.abc.Iterable | None
+        :param bound_vars:
         :return:
         """
-        constraint_component = constraint_component or self.shacl_constraint_class()
+        constraint_component = constraint_component or self.shacl_constraint_component
         severity = self.shape.severity
         sg = self.shape.sg.graph
         r_triples = list()
@@ -225,13 +228,13 @@ class ConstraintComponent(object, metaclass=abc.ABCMeta):
         r_triples.append((r_node, SH_sourceShape, (sg, self.shape.node)))
         r_triples.append((r_node, SH_resultSeverity, severity))
         r_triples.append((r_node, SH_focusNode, (datagraph or sg, focus_node)))
-        if value_node:
+        if value_node is not None:
             r_triples.append((r_node, SH_value, (datagraph, value_node)))
         if result_path is None and self.shape.is_property_shape:
             result_path = self.shape.path()
-        if result_path:
+        if result_path is not None:
             r_triples.append((r_node, SH_resultPath, (sg, result_path)))
-        if source_constraint:
+        if source_constraint is not None:
             r_triples.append((r_node, SH_sourceConstraint, (sg, source_constraint)))
         messages = list(self.shape.message)
         if extra_messages:
@@ -277,13 +280,13 @@ class ConstraintComponent(object, metaclass=abc.ABCMeta):
         return msg
 
 
-SH_nodeValidator = SH.term('nodeValidator')
-SH_propertyValidator = SH.term('propertyValidator')
-SH_validator = SH.term('validator')
-SH_optional = SH.term('optional')
-SH_SPARQLSelectValidator = SH.term('SPARQLSelectValidator')
-SH_SPARQLAskValidator = SH.term('SPARQLAskValidator')
-SH_JSValidator = SH.term('JSValidator')
+SH_nodeValidator = SH.nodeValidator
+SH_propertyValidator = SH.propertyValidator
+SH_validator = SH.validator
+SH_optional = SH.optional
+SH_SPARQLSelectValidator = SH.SPARQLSelectValidator
+SH_SPARQLAskValidator = SH.SPARQLAskValidator
+SH_JSValidator = SH.JSValidator
 
 
 class CustomConstraintComponentFactory(object):
