@@ -6,9 +6,13 @@ import re
 
 import rdflib
 
-from rdflib import RDF, XSD
+from rdflib import XSD
 
 from ..consts import (
+    OWL_PFX,
+    RDF,
+    RDF_PFX,
+    RDFS_PFX,
     SH,
     OWL_Ontology,
     RDF_type,
@@ -24,7 +28,7 @@ from ..consts import (
 from ..errors import ConstraintLoadError, ReportableRuntimeError, ValidationFailure
 
 
-SH_declare = SH.term('declare')
+SH_declare = SH.declare
 invalid_parameter_names = {'this', 'shapesGraph', 'currentShape', 'path', 'PATH', 'value'}
 
 
@@ -34,9 +38,9 @@ class SPARQLQueryHelper(object):
     bind_path_regex = re.compile(r"([\s{}()])[\$\?]PATH", flags=re.M)
     bind_sg_regex = re.compile(r"([\s{}()])[\$\?]shapesGraph", flags=re.M)
     bind_cs_regex = re.compile(r"([\s{}()])[\$\?]currentShape", flags=re.M)
-    has_minus_regex = re.compile(r"[^\?\$]MINUS[\s\{]", flags=re.M | re.I)
-    has_values_regex = re.compile(r"[^\?\$]VALUES[\s\{]", flags=re.M | re.I)
-    has_service_regex = re.compile(r"[^\?\$]SERVICE[\s\<]", flags=re.M | re.I)
+    has_minus_regex = re.compile(r"^(?:[^#]*|M)(?!#)#?[^\?\$\#]M?INUS[\s\{]", flags=re.M | re.I)
+    has_values_regex = re.compile(r"^(?:[^#]*|V)(?!#)#?[^\?\$\#]V?ALUES[\s\{]", flags=re.M | re.I)
+    has_service_regex = re.compile(r"^(?:[^#]*|S)(?!#)#?[^\?\$\#]S?ERVICE[\s\<]", flags=re.M | re.I)
     has_nested_select_regex = re.compile(
         r"SELECT[\s\(\)\$\?\a-z]*\{[^\}]*SELECT\s+((?:(?:[\?\$]\w+\s+)|(?:\*\s+))+)", flags=re.M | re.I
     )
@@ -53,9 +57,9 @@ class SPARQLQueryHelper(object):
         self.param_bind_map = {}
         self.bound_messages = set()
         self.prefixes = {
-            'rdf': rdflib.namespace.RDF.uri,
-            'rdfs': rdflib.namespace.RDFS.uri,
-            'owl': str(rdflib.namespace.OWL),
+            'rdf': RDF_PFX,
+            'rdfs': RDFS_PFX,
+            'owl': OWL_PFX,
         }
         if shape:
             self.shape = shape
@@ -140,7 +144,10 @@ class SPARQLQueryHelper(object):
 
         for prefixes_val in iter(prefixes_vals):
             pfx_declares = set(sg.objects(prefixes_val, SH_declare))
-            all_declares = global_declares.union(pfx_declares)
+            if pfx_declares and prefixes_val in onts:
+                all_declares = pfx_declares.union(ng_declares)
+            else:
+                all_declares = global_declares.union(pfx_declares)
             for dec in iter(all_declares):
                 if isinstance(dec, rdflib.Literal):
                     raise ConstraintLoadError(
@@ -226,7 +233,7 @@ class SPARQLQueryHelper(object):
                 seq1_string = self._shacl_path_to_sparql_path(s, recursion=recursion + 1)
                 all_collected.append(seq1_string)
             if len(all_collected) < 2:
-                raise ReportableRuntimeError("List of SHACL sequence paths " "must have alt least two path items.")
+                raise ReportableRuntimeError("List of SHACL sequence paths must have alt least two path items.")
             return "/".join(all_collected)
 
         find_inverse = set(sg.objects(path_val, SH_inversePath))
@@ -243,7 +250,7 @@ class SPARQLQueryHelper(object):
                 alt1_string = self._shacl_path_to_sparql_path(a, recursion=recursion + 1)
                 all_collected.append(alt1_string)
             if len(all_collected) < 2:
-                raise ReportableRuntimeError("List of SHACL alternate paths " "must have alt least two path items.")
+                raise ReportableRuntimeError("List of SHACL alternate paths must have alt least two path items.")
             return "|".join(all_collected)
 
         find_zero_or_more = set(sg.objects(path_val, SH_zeroOrMorePath))
@@ -319,12 +326,18 @@ class SPARQLQueryHelper(object):
                     # these are optional:
                     if p == "shapesGraph" or p == "currentShape":
                         continue
-                    raise ValidationFailure(
-                        "All potentially pre-bound variables must be selected from a nested SELECT query.\n"
-                        "Potentially pre-bound variables for this query are: {}.".format(
-                            ", ".join(potentially_prebound_variables)
+                    elif p == "this":
+                        raise ValidationFailure(
+                            "All potentially pre-bound variables must be selected from a nested SELECT query.\n"
+                            "Don't forget to include variable `$this` in your SELECT arguments."
+                        )
+                    else:
+                        raise ValidationFailure(
+                            "All potentially pre-bound variables must be selected from a nested SELECT query.\n"
+                            "Potentially pre-bound variables for this query are: {}.".format(
+                                ", ".join(potentially_prebound_variables)
+                            )
                         )
-                    )
         has_as_var = self.has_as_var_regex.search(sparql_text)
         if has_as_var:
             var_name = has_as_var.group(1)
