@@ -6,23 +6,20 @@ import sys
 from decimal import Decimal
 from typing import TYPE_CHECKING, List, Optional, Set, Tuple, Type, Union
 
-from rdflib import RDF, BNode, Literal, URIRef
+from rdflib import BNode, Literal, URIRef
 
 from .consts import (
     RDF_type,
     RDFS_Class,
     RDFS_subClassOf,
-    SH_alternativePath,
     SH_deactivated,
     SH_description,
     SH_Info,
-    SH_inversePath,
     SH_jsFunctionName,
     SH_JSTarget,
     SH_JSTargetType,
     SH_message,
     SH_name,
-    SH_oneOrMorePath,
     SH_order,
     SH_property,
     SH_resultSeverity,
@@ -37,15 +34,15 @@ from .consts import (
     SH_targetSubjectsOf,
     SH_Violation,
     SH_Warning,
-    SH_zeroOrMorePath,
-    SH_zeroOrOnePath,
 )
 from .errors import ConstraintLoadError, ConstraintLoadWarning, ReportableRuntimeError, ShapeLoadError
 from .helper import get_query_helper_cls
+from .helper.expression_helper import value_nodes_from_path
 from .pytypes import GraphLike
 
 
 if TYPE_CHECKING:
+    from pyshacl.constraints import ConstraintComponent
     from pyshacl.shapes_graph import ShapesGraph
 
 module = sys.modules[__name__]
@@ -174,7 +171,23 @@ class Shape(object):
             name = next(iter(self.name))
         except Exception:
             name = str(self.node)
-        return "<Shape {}>".format(name)
+        if self.is_property_shape:
+            kind = "PropertyShape"
+        else:
+            kind = "NodeShape"
+        return "<{} {}>".format(kind, name)
+
+    def __repr__(self):
+        if self.is_property_shape:
+            p = "True"
+        else:
+            p = "False"
+        names = list(self.name)
+        if len(names):
+            return "<Shape {} p={} node={}>".format(",".join(names), p, str(self.node))
+        else:
+            return "<Shape p={} node={}>".format(p, str(self.node))
+        # return super(Shape, self).__repr__()
 
     @property
     def description(self):
@@ -327,7 +340,7 @@ class Shape(object):
         for tc in target_classes:
             s = data_graph.subjects(RDF_type, tc)
             found_target_instances.update(s)
-            subc = data_graph.subjects(RDFS_subClassOf, tc)
+            subc = data_graph.transitive_subjects(RDFS_subClassOf, tc)
             for subclass in iter(subc):
                 if subclass == tc:
                     continue
@@ -368,109 +381,6 @@ class Shape(object):
                         found_node_targets.add(t)
         return found_node_targets
 
-    @classmethod
-    def value_nodes_from_path(cls, sg, focus, path_val, target_graph, recursion=0):
-        # Link: https://www.w3.org/TR/shacl/#property-paths
-        if isinstance(path_val, URIRef):
-            return set(target_graph.objects(focus, path_val))
-        elif isinstance(path_val, Literal):
-            raise ReportableRuntimeError("Values of a property path cannot be a Literal.")
-        # At this point, path_val _must_ be a BNode
-        # TODO, the path_val BNode must be value of exactly one sh:path subject in the SG.
-        if recursion >= 10:
-            raise ReportableRuntimeError("Path traversal depth is too much!")
-        find_list = set(sg.graph.objects(path_val, RDF.first))
-        if len(find_list) > 0:
-            first_node = next(iter(find_list))
-            rest_nodes = set(sg.graph.objects(path_val, RDF.rest))
-            go_deeper = True
-            if len(rest_nodes) < 1:
-                if recursion == 0:
-                    raise ReportableRuntimeError("A list of SHACL Paths must contain at least two path items.")
-                else:
-                    go_deeper = False
-            rest_node = next(iter(rest_nodes))
-            if rest_node == RDF.nil:
-                if recursion == 0:
-                    raise ReportableRuntimeError("A list of SHACL Paths must contain at least two path items.")
-                else:
-                    go_deeper = False
-            this_level_nodes = cls.value_nodes_from_path(sg, focus, first_node, target_graph, recursion=recursion + 1)
-            if not go_deeper:
-                return this_level_nodes
-            found_value_nodes = set()
-            for tln in iter(this_level_nodes):
-                value_nodes = cls.value_nodes_from_path(sg, tln, rest_node, target_graph, recursion=recursion + 1)
-                found_value_nodes.update(value_nodes)
-            return found_value_nodes
-
-        find_inverse = set(sg.graph.objects(path_val, SH_inversePath))
-        if len(find_inverse) > 0:
-            inverse_path = next(iter(find_inverse))
-            return set(target_graph.subjects(inverse_path, focus))
-
-        find_alternatives = set(sg.graph.objects(path_val, SH_alternativePath))
-        if len(find_alternatives) > 0:
-            alternatives_list = next(iter(find_alternatives))
-            all_collected = set()
-            visited_alternatives = 0
-            for a in sg.graph.items(alternatives_list):
-                found_nodes = cls.value_nodes_from_path(sg, focus, a, target_graph, recursion=recursion + 1)
-                visited_alternatives += 1
-                all_collected.update(found_nodes)
-            if visited_alternatives < 2:
-                raise ReportableRuntimeError("List of SHACL alternate paths must have at least two path items.")
-            return all_collected
-
-        find_zero_or_more = set(sg.graph.objects(path_val, SH_zeroOrMorePath))
-        if len(find_zero_or_more) > 0:
-            zm_path = next(iter(find_zero_or_more))
-            collection_set = set()
-            # Note, the zero-or-more path always includes the current subject too!
-            collection_set.add(focus)
-            found_nodes = cls.value_nodes_from_path(sg, focus, zm_path, target_graph, recursion=recursion + 1)
-            search_deeper_nodes = set(iter(found_nodes))
-            while len(search_deeper_nodes) > 0:
-                current_node = search_deeper_nodes.pop()
-                if current_node in collection_set:
-                    continue
-                collection_set.add(current_node)
-                found_more_nodes = cls.value_nodes_from_path(
-                    sg, current_node, zm_path, target_graph, recursion=recursion + 1
-                )
-                search_deeper_nodes.update(found_more_nodes)
-            return collection_set
-
-        find_one_or_more = set(sg.graph.objects(path_val, SH_oneOrMorePath))
-        if len(find_one_or_more) > 0:
-            one_or_more_path = next(iter(find_one_or_more))
-            collection_set = set()
-            found_nodes = cls.value_nodes_from_path(sg, focus, one_or_more_path, target_graph, recursion=recursion + 1)
-            # Note, the one-or-more path should _not_ include the current focus
-            search_deeper_nodes = set(iter(found_nodes))
-            while len(search_deeper_nodes) > 0:
-                current_node = search_deeper_nodes.pop()
-                if current_node in collection_set:
-                    continue
-                collection_set.add(current_node)
-                found_more_nodes = cls.value_nodes_from_path(
-                    sg, current_node, one_or_more_path, target_graph, recursion=recursion + 1
-                )
-                search_deeper_nodes.update(found_more_nodes)
-            return collection_set
-
-        find_zero_or_one = set(sg.graph.objects(path_val, SH_zeroOrOnePath))
-        if len(find_zero_or_one) > 0:
-            zero_or_one_path = next(iter(find_zero_or_one))
-            collection_set = set()
-            # Note, the zero-or-one path always includes the current subject too!
-            collection_set.add(focus)
-            found_nodes = cls.value_nodes_from_path(sg, focus, zero_or_one_path, target_graph, recursion=recursion + 1)
-            collection_set.update(found_nodes)
-            return collection_set
-
-        raise NotImplementedError("That path method to get value nodes of property shapes is not yet implemented.")
-
     def value_nodes(self, target_graph, focus):
         """
         For each focus node, you can get a set of value nodes.
@@ -487,7 +397,7 @@ class Shape(object):
         path_val = self.path()
         focus_dict = {}
         for f in focus:
-            focus_dict[f] = self.value_nodes_from_path(self.sg, f, path_val, target_graph)
+            focus_dict[f] = value_nodes_from_path(self.sg, f, path_val, target_graph)
         return focus_dict
 
     def find_custom_constraints(self):
@@ -499,7 +409,7 @@ class Shape(object):
                 path = mandatory_param.path()
                 assert isinstance(path, URIRef)
                 found_vals = set(self.sg.objects(self.node, path))
-                # found_vals = self._value_nodes_from_path(self.node, mandatory_param.path(), self.sg.graph)
+                # found_vals = value_nodes_from_path(self.node, mandatory_param.path(), self.sg.graph)
                 found_all_mandatory = found_all_mandatory and bool(len(found_vals) > 0)
             if found_all_mandatory:
                 applicable_custom_constraints.add(c)
@@ -545,13 +455,19 @@ class Shape(object):
             setattr(module, 'CONSTRAINT_PARAMS', (ALL_CONSTRAINT_PARAMETERS, CONSTRAINT_PARAMETERS_MAP))
             CONSTRAINT_PARAMETERS = ALL_CONSTRAINT_PARAMETERS
             PARAMETER_MAP = CONSTRAINT_PARAMETERS_MAP
-        if self.sg.js_enabled:
+        if self.sg.js_enabled or self._advanced:
             search_parameters = CONSTRAINT_PARAMETERS.copy()
             constraint_map = PARAMETER_MAP.copy()
-            from pyshacl.extras.js.constraint import JSConstraint, SH_js
+            if self._advanced:
+                from pyshacl.constraints.advanced import ExpressionConstraint, SH_expression
 
-            search_parameters.append(SH_js)
-            constraint_map[SH_js] = JSConstraint
+                search_parameters.append(SH_expression)
+                constraint_map[SH_expression] = ExpressionConstraint
+            if self.sg.js_enabled:
+                from pyshacl.extras.js.constraint import JSConstraint, SH_js
+
+                search_parameters.append(SH_js)
+                constraint_map[SH_js] = JSConstraint
         else:
             search_parameters = CONSTRAINT_PARAMETERS
             constraint_map = PARAMETER_MAP
@@ -570,8 +486,9 @@ class Shape(object):
         done_constraints = set()
         run_count = 0
         _evaluation_path.append(self)
+        # print(_evaluation_path)
         constraint_components = [constraint_map[p] for p in iter(parameters)]
-        for constraint_component in constraint_components:
+        for constraint_component in constraint_components:  # type: Type[ConstraintComponent]
             if constraint_component in done_constraints:
                 continue
             try:
@@ -613,4 +530,5 @@ class Shape(object):
             non_conformant = non_conformant or (not _is_conform)
             reports.extend(_r)
             run_count += 1
+        # print(_evaluation_path, "Passes" if not non_conformant else "Fails")
         return (not non_conformant), reports
